//-*-c++-*-
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "tulip/String.h"
#include "tulip/SuperGraph.h"
#include "tulip/StringProxy.h"
String::String (const PropertyContext & context):Property<StringType , StringType>(context) {
  stringProxy=(StringProxy *)context.propertyProxy;
}

